@@ -1,5 +1,6 @@
 package PDK::Device::ConfigBackup;
 
+use utf8;
 use v5.30;
 use Moose;
 use Carp       qw(croak);
@@ -47,15 +48,17 @@ has result => (
 );
 
 sub getConfigJob {
-  my ($self, $devices) = @_;
+  my ($self, @args) = @_;
+
+  my @devices = @args == 1 && ref $args[0] eq 'ARRAY' ? @{$args[0]} : @args;
 
   eval {
-    $devices = $self->assignAttributes($devices);
-    my $count = scalar(@{$devices});
-    $self->dump("开始配置备份任务：并行执行 ($count) 台设备的配置获取任务");
+    @devices = $self->assignPdkModules(@devices);
+    my $count = scalar(@devices);
+    $self->dump("[getConfigJob] 开始配置备份任务：并行执行 ($count) 台设备的配置获取任务");
   };
   if (!!$@) {
-    croak "自动加载并装配模块抛出异常: $@";
+    croak "[getConfigJob] 自动加载并装配模块抛出异常: $@";
   }
 
   my $pm    = Parallel::ForkManager->new($self->{queue});
@@ -66,8 +69,8 @@ sub getConfigJob {
     $queue->enqueue($data) if defined $data;
   });
 
-  foreach my $device (@{$devices}) {
-    $self->dump("开始子任务：发起设备 ($device->{name}/$device->{ip}) 配置备份任务");
+  foreach my $device (@devices) {
+    $self->dump("[getConfigJob] 开始子任务：发起设备 ($device->{name}/$device->{ip}) 配置备份任务");
     $pm->start and next;
     my $status = $self->startGetConfig($device);
     $pm->finish(0, $status);
@@ -78,27 +81,29 @@ sub getConfigJob {
   while (my $data = $queue->dequeue_nb()) {
     push @{$result->{$_}}, @{$data->{$_}} for qw(success fail);
   }
-  $self->dump("配置备份任务执行完毕，正在将运行结果写入日志文件中");
+  $self->dump("[getConfigJob] 配置备份任务执行完毕，正在将运行结果写入日志文件中");
 
   for my $type (qw(success fail)) {
     if (@{$result->{$type}}) {
       my $text = join("\n", @{$result->{$type}});
       my $flag = $type eq 'success' ? '成功' : '失败';
-      $self->write_file($text, "配置备份${flag}_设备清单");
+      $self->write_file($text, "配置备份${flag}_设备清单.txt");
     }
   }
 }
 
 sub ftpConfigJob {
-  my ($self, $devices) = @_;
+  my ($self, @args) = @_;
+
+  my @devices = @args == 1 && ref $args[0] eq 'ARRAY' ? @{$args[0]} : @args;
 
   eval {
-    $devices = $self->assignAttributes($devices);
-    my $count = scalar(@{$devices});
-    $self->dump("开始FTP配置备份任务：并行执行 ($count) 台设备的配置获取任务");
+    @devices = $self->assignPdkModules(@devices);
+    my $count = scalar(@devices);
+    $self->dump("[ftpConfigJob] 开始FTP配置备份任务：并行执行 ($count) 台设备的配置获取任务");
   };
   if (!!$@) {
-    croak "自动加载并装配模块抛出异常: $@";
+    croak "[ftpConfigJob] 自动加载并装配模块抛出异常: $@";
   }
 
   my $pm    = Parallel::ForkManager->new($self->{queue});
@@ -109,8 +114,8 @@ sub ftpConfigJob {
     $queue->enqueue($data) if defined $data;
   });
 
-  foreach my $device (@{$devices}) {
-    $self->dump("开始子任务：发起设备 ($device->{name}/$device->{ip}) FTP配置备份任务");
+  foreach my $device (@devices) {
+    $self->dump("[ftpConfigJob] 开始子任务：发起设备 ($device->{name}/$device->{ip}) FTP配置备份任务");
     $pm->start and next;
     my $status = $self->startFtpConfig($device);
     $pm->finish(0, $status);
@@ -121,27 +126,29 @@ sub ftpConfigJob {
   while (my $data = $queue->dequeue_nb()) {
     push @{$result->{$_}}, @{$data->{$_}} for qw(success fail);
   }
-  $self->dump("FTP配置备份任务执行完毕，正在将运行结果写入日志文件中");
+  $self->dump("[ftpConfigJob] FTP配置备份任务执行完毕，正在将运行结果写入日志文件中");
 
   for my $type (qw(success fail)) {
     if (@{$result->{$type}}) {
       my $text = join("\n", @{$result->{$type}});
       my $flag = $type eq 'success' ? '成功' : '失败';
-      $self->write_file($text, "FTP备份${flag}_设备清单");
+      $self->write_file($text, "FTP备份${flag}_设备清单.txt");
     }
   }
 }
 
 sub execCommandsJob {
-  my ($self, $devices, $commands) = @_;
+  my ($self, $commands, @args) = @_;
+
+  my @devices = @args == 1 && ref $args[0] eq 'ARRAY' ? @{$args[0]} : @args;
 
   eval {
-    $devices = $self->assignAttributes($devices);
-    my $count = scalar(@{$devices});
-    $self->dump("开始任务：并行执行 ($count) 台设备的配置下发任务，各设备推送的脚本一致");
+    @devices = $self->assignPdkModules(@devices);
+    my $count = scalar(@devices);
+    $self->dump("[execCommandsJob] 开始任务：并行执行 ($count) 台设备的配置下发任务，各设备推送的脚本一致");
   };
   if (!!$@) {
-    croak "自动加载并装配模块抛出异常: $@";
+    croak "[execCommandsJob] 自动加载并装配模块抛出异常: $@";
   }
 
   my $pm    = Parallel::ForkManager->new($self->{queue});
@@ -152,8 +159,8 @@ sub execCommandsJob {
     $queue->enqueue($data) if defined $data;
   });
 
-  foreach my $device (@{$devices}) {
-    $self->dump("开始子任务：发起设备 ($device->{name}/$device->{ip}) 脚本自动下发任务");
+  foreach my $device (@devices) {
+    $self->dump("[execCommandsJob] 开始子任务：发起设备 ($device->{name}/$device->{ip}) 脚本自动下发任务");
     $pm->start and next;
     my $status = $self->startExecCommands($device, $commands);
     $pm->finish(0, $status);
@@ -164,34 +171,40 @@ sub execCommandsJob {
   while (my $data = $queue->dequeue_nb()) {
     push @{$result->{$_}}, @{$data->{$_}} for qw(success fail);
   }
-  $self->dump("脚本自动下发任务执行完毕，正在将运行结果写入日志文件中");
+  $self->dump("[execCommandsJob] 脚本自动下发任务执行完毕，正在将运行结果写入日志文件中");
 
   for my $type (qw(success fail)) {
     if (@{$result->{$type}}) {
       my $text = join("\n", @{$result->{$type}});
       my $flag = $type eq 'success' ? '成功' : '失败';
-      $self->write_file($text, "配置下发${flag}_设备清单");
+      $self->write_file($text, "配置下发${flag}_设备清单.txt");
     }
   }
 }
 
 sub runCommandsJob {
-  my ($self, $devices) = @_;
+  my ($self, @args) = @_;
 
-  foreach my $device (@{$devices}) {
+  my @devices = @args == 1 && ref $args[0] eq 'ARRAY' ? @{$args[0]} : @args;
+  my @actives = ();
+
+  foreach my $device (@devices) {
     if (!$device->{commands} || @{$device->{commands}} == 0) {
-      $self->dump("[runCommandsJob/前置检查阶段]：所有设备的命令列表都不能为空");
-      croak "设备 " . $device->{name} . " 的命令列表为空";
+      $self->dump("[runCommandsJob/前置检查阶段]：设备 ($device->{name}/$device->{ip}) 配置下发列表不能为空，将自动跳过");
+    }
+    else {
+      push @actives, $device;
+      $self->dump("[runCommandsJob/前置检查阶段]：设备 ($device->{name}/$device->{ip}) 包含下发配置列表，符合配置自动下发规则");
     }
   }
 
   eval {
-    $devices = $self->assignAttributes($devices);
-    my $count = scalar(@{$devices});
-    $self->dump("开始配置推送任务：并行执行 ($count) 台设备的配置下发任务，推送的脚本各自独立");
+    @actives = $self->assignPdkModules(@actives);
+    my $count = scalar(@actives);
+    $self->dump("[runCommandsJob] 开始配置推送任务：并行执行 ($count) 台设备的配置下发任务，推送的脚本各自独立");
   };
   if (!!$@) {
-    croak "自动加载并装配模块抛出异常: $@";
+    croak "[runCommandsJob] 自动加载并装配模块抛出异常: $@";
   }
 
   my $pm    = Parallel::ForkManager->new(10);
@@ -202,8 +215,8 @@ sub runCommandsJob {
     $queue->enqueue($data) if defined $data;
   });
 
-  foreach my $device (@{$devices}) {
-    $self->dump("开始子任务：发起设备 ($device->{name}/$device->{ip}) 脚本自动下发(高权模式)任务");
+  foreach my $device (@actives) {
+    $self->dump("[runCommandsJob] 开始子任务：发起设备 ($device->{name}/$device->{ip}) 脚本自动下发(高权模式)任务");
     $pm->start and next;
     my $commands = $device->{commands};
     my $status   = $self->startExecCommands($device, $commands);
@@ -215,28 +228,29 @@ sub runCommandsJob {
   while (my $data = $queue->dequeue_nb()) {
     push @{$result->{$_}}, @{$data->{$_}} for qw(success fail);
   }
-  $self->dump("脚本自动下发(高权模式)任务执行完毕，正在将运行结果写入日志文件中");
+  $self->dump("[runCommandsJob] 脚本自动下发(高权模式)任务执行完毕，正在将运行结果写入日志文件中");
 
   for my $type (qw(success fail)) {
     if (@{$result->{$type}}) {
       my $text = join("\n", @{$result->{$type}});
       my $flag = $type eq 'success' ? '成功' : '失败';
-      $self->write_file($text, "配置下发${flag}_设备清单");
+      $self->write_file($text, "配置下发${flag}_设备清单.txt");
     }
   }
 }
 
 sub ftpConfig {
   my ($self, $param) = @_;
-  $self->dump("开始FTP配置备份任务：对设备($param->{name}/$param->{ip})执行 FTP 备份操作");
+  $self->dump("[ftpConfig] 开始FTP配置备份任务：对设备($param->{name}/$param->{ip})执行 FTP 备份操作");
 
   my $result;
   eval {
-    my $device     = $self->initPdkDevice($param);
     my $hostname   = $param->{name};
     my $ftp_server = $param->{ftp_server} // $ENV{PDK_FTP_SERVER};
 
-    croak "启用 FTP 备份配置，必须正确配置 FTP 服务器地址和设备名称" unless $ftp_server && $hostname;
+    croak "[ftpConfig] 启用 FTP 备份配置，必须正确配置 FTP 服务器地址和设备名称" unless $ftp_server && $hostname;
+
+    my $device = $self->initPdkDevice($param);
 
     $device->ftpConfig($hostname, $ftp_server);
     $result = {success => 1};
@@ -250,7 +264,7 @@ sub ftpConfig {
 
 sub getConfig {
   my ($self, $param) = @_;
-  $self->dump("开始配置备份任务：对设备($param->{name}/$param->{ip})执行配置获取操作");
+  $self->dump("[getConfig] 开始配置备份任务：对设备($param->{name}/$param->{ip})执行配置获取操作");
 
   my $result;
   eval {
@@ -266,7 +280,7 @@ sub getConfig {
 
 sub execCommands {
   my ($self, $param, $commands) = @_;
-  $self->dump("开始配置下发任务：对设备($param->{name}/$param->{ip})执行命令下发操作");
+  $self->dump("[execCommands] 开始配置下发任务：对设备($param->{name}/$param->{ip})执行命令下发操作");
 
   my $result;
   eval {
@@ -282,7 +296,7 @@ sub execCommands {
 
 sub startFtpConfig {
   my ($self, $param) = @_;
-  $self->dump("激活FTP备份成功任务：对设备($param->{name}/$param->{ip})执行 FTP 备份并记录结果");
+  $self->dump("[startFtpConfig] 激活FTP备份成功任务：对设备($param->{name}/$param->{ip})执行 FTP 备份并记录结果");
 
   my $name = $param->{name};
   my $ip   = $param->{ip};
@@ -292,11 +306,11 @@ sub startFtpConfig {
 
   if ($result->{success}) {
     push @{$status->{success}}, $self->now . " - 设备 $name($ip) FTP 备份成功";
-    $self->dump("FTP备份成功：设备 $name($ip) FTP 备份成功");
+    $self->dump("[startFtpConfig] FTP备份成功：设备 $name($ip) FTP 备份成功");
   }
   else {
     push @{$status->{fail}}, $self->now . " - 设备 $name($ip) FTP 备份失败: $result->{reason}";
-    $self->dump("FTP备份失败：设备 $name($ip) FTP 备份异常: $result->{reason}");
+    $self->dump("[startFtpConfig] FTP备份失败：设备 $name($ip) FTP 备份异常: $result->{reason}");
   }
 
   return $status;
@@ -304,7 +318,7 @@ sub startFtpConfig {
 
 sub startExecCommands {
   my ($self, $param, $commands) = @_;
-  $self->dump("激活配置下发任务：对设备($param->{name}/$param->{ip})命令下发并记录结果");
+  $self->dump("[startExecCommands] 激活配置下发任务：对设备($param->{name}/$param->{ip})命令下发并记录结果");
 
   my $name = $param->{name};
   my $ip   = $param->{ip};
@@ -316,11 +330,11 @@ sub startExecCommands {
     push @{$status->{success}}, $self->now . " - 设备 $name($ip) 配置下发成功";
     my $filename = "${name}_${ip}_execCommands.txt";
     $self->write_file($result->{result}, $filename);
-    $self->dump("配置下发成功：设备 $name($ip) 配置下发成功，快照保存在文件 $filename");
+    $self->dump("[startExecCommands] 配置下发成功：设备 $name($ip) 配置下发成功，快照保存在文件 $filename");
   }
   else {
     push @{$status->{fail}}, $self->now . " - 设备 $name($ip) 配置下发失败: $result->{reason}";
-    $self->dump("配置下发失败：设备 $name($ip) 配置下发异常: $result->{reason}");
+    $self->dump("[startExecCommands] 配置下发失败：设备 $name($ip) 配置下发异常: $result->{reason}");
   }
 
   return $status;
@@ -329,7 +343,7 @@ sub startExecCommands {
 sub startGetConfig {
   my ($self, $param) = @_;
 
-  $self->dump("激活配置备份任务：对设备($param->{name}/$param->{ip})配置获取并记录结果");
+  $self->dump("[startGetConfig] 激活配置备份任务：对设备($param->{name}/$param->{ip})配置获取并记录结果");
 
   my $name = $param->{name};
   my $ip   = $param->{ip};
@@ -341,11 +355,11 @@ sub startGetConfig {
     push @{$status->{success}}, $self->now . " - 设备 $name($ip) 配置备份成功";
     my $filename = "${name}_${ip}_getConfig.txt";
     $self->write_file($result->{config}, $filename);
-    $self->dump("配置备份成功：设备 $name($ip) 配置备份成功，快照保存在文件 $filename");
+    $self->dump("[startGetConfig] 配置备份成功：设备 $name($ip) 配置备份成功，快照保存在文件 $filename");
   }
   else {
     push @{$status->{fail}}, $self->now . " - 设备 $name($ip) 配置备份失败: $result->{reason}";
-    $self->dump("配置备份失败：设备 $name($ip) 配置备份任务异常: $result->{reason}");
+    $self->dump("[startGetConfig] 配置备份失败：设备 $name($ip) 配置备份任务异常: $result->{reason}");
   }
 
   return $status;
@@ -366,9 +380,9 @@ sub dump {
     make_path($workdir) unless -d $workdir;
 
     my $filename = "$workdir/backup_dump.txt";
-    open(my $fh, '>>', $filename) or croak "无法打开文件 $filename 进行写入: $!";
-    print $fh "$text\n"           or croak "写入文件 $filename 失败: $!";
-    close($fh)                    or croak "关闭文件句柄 $filename 失败: $!";
+    open(my $fh, '>>encoding(UTF-8)', $filename) or croak "无法打开文件 $filename 进行写入: $!";
+    print $fh "$text\n"                          or croak "写入文件 $filename 失败: $!";
+    close($fh)                                   or croak "关闭文件句柄 $filename 失败: $!";
   }
 }
 
